#pylint: disable=line-too-long,attribute-defined-outside-init
'''
    References come in lists, but how do you look them up?
    This way!
'''
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# Version 0.1 by Pat Riehecky <riehecky@fnal.gov> for Scientific Linux

# for python3 compat
from __future__ import unicode_literals
from __future__ import absolute_import

import sys

try:
    import xml.etree.cElementTree as xmletree
except ImportError:  # pragma: no cover
    import xml.etree.ElementTree as xmletree

class ReferenceStoreEvents(object):
    '''
        I am the behavioral logic
    '''
    def __init__(self):
        '''setup'''
        pass

    def __delitem__(self, key):
        '''
           Used for: removing  like a dict
        '''
        del self._reflist[key]

    def __setitem__(self, key, value):
        '''
             For simply adding a reference (no merge)
        '''
        if not isinstance(value, type(self.Reference())):
            raise TypeError('I can only add ' + str(type(self.Reference())) + ' type objects, not ' + str(type(value)))

        if key != value.href:
            raise ValueError('Incorrect href, should have been "' + value.href + '"')

        self._reflist[key] = value

    def add(self, ref, merge=True):
        '''add a reference to the list'''
        if xmletree.iselement(ref):
            _tmp = self.Reference()
            _tmp.xmletree = ref
            ref = _tmp

        if not isinstance(ref, type(self.Reference())):
            raise TypeError('I can only add ReferenceModel type objects')

        if not ref.href:
            raise ValueError('No href specified')
        if not ref.reftype:
            raise ValueError('No reftype specified')

        if ref.href in self:
            if merge:
                self[ref.href] = self._merge_attributes(self[ref.href], ref)
            else:
                raise ValueError('Adding duplicate when merge disabled')
        else:
            self[ref.href] = ref

        self._setup_byreftype_dict()

        if ref.href in self:
            return True

        raise RuntimeError('Attempted to add ref, but not found after add')  # pragma: no cover

    def create(self, reftype=None, href=None, refid=None, title=None, merge=True):
        '''Add a new reference to this store'''
        ref = self.Reference(reftype=reftype, href=href, refid=refid, title=title)
        return self.add(ref, merge)

    def remove(self, obj):
        '''so you can do a remove'''
        href = None
        if isinstance(obj, type(self.Reference())):
            href = obj.href
        elif isinstance(obj, str):
            href = obj
        elif (sys.version_info < (3, 0)):
            # I'm a hack for py2/3 compat!
            if isinstance(obj, unicode):
                href = obj
            else:
                raise ValueError('Pass either the href, or the ref object to remove')
        else:
            raise ValueError('Pass either the href, or the ref object to remove')

        del self[href]

        self._setup_byreftype_dict()

        if href not in self:
            return True

        raise RuntimeError('Attempted to remove ref, but found after remove')  # pragma: no cover

    def _setup_byreftype_dict(self):
        '''The byreftype dict is a quick ref we need to maintain'''
        for reftype in self.reftypes:
            self._byreftype[reftype] = []

        for href in self.urls:
            self._byreftype[self[href].reftype].append(self[href])

        for reftype in self._byreftype:
            self._byreftype[reftype] = tuple(self._byreftype[reftype])

    @staticmethod
    def _merge_attributes(existing, ref):
        '''
            Attributes in the 'ref' will, if defined, override the existing ones
        '''
        if ref.refid:
            existing.refid = ref.refid
        if ref.title:
            existing.title = ref.title
        if ref.reftype:
            existing.reftype = ref.reftype

        return existing
